@@ -82,6 +82,9 @@
 #include "xfce-desktop.h"
 #include "xfce-desktop-enum-types.h"
 
+/* disable setting the x background for bug 7442 */
+//#define DISABLE_FOR_BUG7442
+
 struct _XfceDesktopPriv
 {
     GdkScreen *gscreen;
@@ -275,7 +278,7 @@ static void
 set_real_root_window_pixmap(GdkScreen *gscreen,
                             GdkPixmap *pmap)
 {
-#if 0 /* see bug #7442 */
+#ifndef DISABLE_FOR_BUG7442
     Window xid;
     GdkWindow *groot;
     
@@ -528,6 +531,13 @@ screen_set_selection(XfceDesktop *desktop)
     selection_atom = XInternAtom(GDK_DISPLAY(), selection_name, False);
     manager_atom = XInternAtom(GDK_DISPLAY(), "MANAGER", False);
 
+    /* the previous check in src/main.c occurs too early, so workaround by
+     * adding this one. */
+   if(XGetSelectionOwner(GDK_DISPLAY(), selection_atom) != None) {
+       g_warning("%s: already running, quitting.", PACKAGE);
+       exit(0);
+   }
+
     XSelectInput(GDK_DISPLAY(), xwin, PropertyChangeMask | ButtonPressMask);
     XSetSelectionOwner(GDK_DISPLAY(), selection_atom, xwin, GDK_CURRENT_TIME);
 
@@ -858,7 +868,7 @@ xfce_desktop_unrealize(GtkWidget *widget)
     gdk_property_delete(groot, gdk_atom_intern("XFCE_DESKTOP_WINDOW", FALSE));
     gdk_property_delete(groot, gdk_atom_intern("NAUTILUS_DESKTOP_WINDOW_ID", FALSE));
 
-#if 0 /* see bug #7442 */
+#ifndef DISABLE_FOR_BUG7442
     gdk_property_delete(groot, gdk_atom_intern("_XROOTPMAP_ID", FALSE));
     gdk_property_delete(groot, gdk_atom_intern("ESETROOT_PMAP_ID", FALSE));
     gdk_window_set_back_pixmap(groot, NULL, FALSE);
@@ -900,8 +910,11 @@ xfce_desktop_button_press_event(GtkWidget *w,
     g_return_val_if_fail(XFCE_IS_DESKTOP(w), FALSE);
 
     if(evt->type == GDK_BUTTON_PRESS) {
-        if(XFCE_DESKTOP(w)->priv->icons_style == XFCE_DESKTOP_ICON_STYLE_NONE
-           && (button == 3 || (button == 1 && (state & GDK_SHIFT_MASK)))) {
+        if(button == 3 || (button == 1 && (state & GDK_SHIFT_MASK))) {
+#ifdef ENABLE_DESKTOP_ICONS
+            if(XFCE_DESKTOP(w)->priv->icons_style != XFCE_DESKTOP_ICON_STYLE_NONE)
+                return FALSE;
+#endif
             xfce_desktop_popup_root_menu(XFCE_DESKTOP(w),
                                          button,
                                          evt->time);
